/* buf_u8.h -- uint8_t shared buffer */
#define BUF_PREFIX       buf_u8
#define BUF_ELEM_TYPE    uint8_t
#define BUF_ELEM_SIZE    1
#define BUF_VARIANT_ID   2
#define BUF_HAS_COUNTERS
#include "buf_generic.h"
