/* buf_i32.h -- int32_t shared buffer */
#define BUF_PREFIX       buf_i32
#define BUF_ELEM_TYPE    int32_t
#define BUF_ELEM_SIZE    4
#define BUF_VARIANT_ID   5
#define BUF_HAS_COUNTERS
#include "buf_generic.h"
