/* buf_i16.h -- int16_t shared buffer */
#define BUF_PREFIX       buf_i16
#define BUF_ELEM_TYPE    int16_t
#define BUF_ELEM_SIZE    2
#define BUF_VARIANT_ID   3
#define BUF_HAS_COUNTERS
#include "buf_generic.h"
