/* buf_f64.h -- double shared buffer */
#define BUF_PREFIX       buf_f64
#define BUF_ELEM_TYPE    double
#define BUF_ELEM_SIZE    8
#define BUF_VARIANT_ID   10
#define BUF_IS_FLOAT
#include "buf_generic.h"
