/* buf_f32.h -- float shared buffer */
#define BUF_PREFIX       buf_f32
#define BUF_ELEM_TYPE    float
#define BUF_ELEM_SIZE    4
#define BUF_VARIANT_ID   9
#define BUF_IS_FLOAT
#include "buf_generic.h"
