/* buf_u64.h -- uint64_t shared buffer */
#define BUF_PREFIX       buf_u64
#define BUF_ELEM_TYPE    uint64_t
#define BUF_ELEM_SIZE    8
#define BUF_VARIANT_ID   8
#define BUF_HAS_COUNTERS
#include "buf_generic.h"
