/* buf_i8.h -- int8_t shared buffer */
#define BUF_PREFIX       buf_i8
#define BUF_ELEM_TYPE    int8_t
#define BUF_ELEM_SIZE    1
#define BUF_VARIANT_ID   1
#define BUF_HAS_COUNTERS
#include "buf_generic.h"
