/* buf_u32.h -- uint32_t shared buffer */
#define BUF_PREFIX       buf_u32
#define BUF_ELEM_TYPE    uint32_t
#define BUF_ELEM_SIZE    4
#define BUF_VARIANT_ID   6
#define BUF_HAS_COUNTERS
#include "buf_generic.h"
