/* buf_u16.h -- uint16_t shared buffer */
#define BUF_PREFIX       buf_u16
#define BUF_ELEM_TYPE    uint16_t
#define BUF_ELEM_SIZE    2
#define BUF_VARIANT_ID   4
#define BUF_HAS_COUNTERS
#include "buf_generic.h"
