/* buf_i64.h -- int64_t shared buffer */
#define BUF_PREFIX       buf_i64
#define BUF_ELEM_TYPE    int64_t
#define BUF_ELEM_SIZE    8
#define BUF_VARIANT_ID   7
#define BUF_HAS_COUNTERS
#include "buf_generic.h"
